package info.aspirecn.cloud.yysj.controller;

import info.aspirecn.cloud.yysj.entity.*;
import info.aspirecn.cloud.yysj.service.ExpenseManagementSercice;
import info.aspirecn.cloud.yysj.service.OrderActionInterface;
import info.aspirecn.cloud.yysj.utils.Constant;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 费用管理，充值记录、账单明细，接口
 *
 * @author lixinxu
 */
@Api(tags = "费用管理接口")
@ApiResponses({
        @ApiResponse(code = 200, message = "成功处理请求"),
        @ApiResponse(code = 400, message = "没有找到该用户信息"),
        @ApiResponse(code = 401, message = "没有权限访问该服务"),
        @ApiResponse(code = 403, message = "权限不足无法访问该服务"),
        @ApiResponse(code = 404, message = "未发现该微服务"),
        @ApiResponse(code = 500, message = "服务器内部错误")
})
@RestController
public class ExpenseManagementController {

    @Autowired
    private ExpenseManagementSercice expenseManagementSercice;

    @ApiOperation(value = "充值记录", notes = "充值记录列表")
    @PostMapping("/queryrecharge")
    private ResponseInfo queryRechargeInfoList(HttpServletResponse response,
                                               @ApiParam(value="用户ID")@RequestHeader()  String userId,
                                               @RequestBody QueryParam queryParam){

        queryParam.setUserId(userId);
        queryParam.setBeginTime(queryParam.getBeginTime());
        queryParam.setEndTime(queryParam.getEndTime());
        queryParam.setPageSize(queryParam.getPageSize());
        queryParam.setPageNum(queryParam.getPageNum());

        //map里有数据列表和查询总条数
        Map<String, Object> reMap = expenseManagementSercice.queryRechargeInfoList(queryParam);
        if (reMap == null){
            return new ResponseInfo().setMessage("数据深度不能大于1000条");
        }

        //取出数据
        List<RechargeInfo> carList = (List<RechargeInfo>)reMap.get(Constant.DATA_LIST);
        Integer total = (Integer)reMap.get(Constant.TOTAL);

        //页面信息, 放到响应头
        response.addHeader("pageSize", Integer.toString(queryParam.getPageSize()));
        response.addHeader("pageNum", Integer.toString(queryParam.getPageNum()));
        response.addHeader("pageTotal", Integer.toString(total%queryParam.getPageSize() > 0 ? total/queryParam.getPageSize()+1 : total/queryParam.getPageSize()));
        response.addHeader("total", Integer.toString(total));

        return new ResponseInfo().setData(carList);
    }

}
