package info.aspirecn.cloud.yysj.service.impl;

import info.aspirecn.cloud.yysj.entity.*;
import info.aspirecn.cloud.yysj.mapper.ExpenseManagementMapper;
import info.aspirecn.cloud.yysj.service.ExpenseManagementSercice;
import info.aspirecn.cloud.yysj.service.OrderActionInterface;
import info.aspirecn.cloud.yysj.utils.Constant;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Email:lixinxu@aspirecn.com
 * Descrption:
 */
@Slf4j
@Service
public class ExpenseManagementSerciceImpl implements ExpenseManagementSercice {

    @Autowired
    private OrderActionInterface orderActionInterface;

    @Autowired
    private ExpenseManagementMapper expenseManagementMapper;

    /**
     * 查询充值记录列表
     *
     * @param queryParam
     */
    @Override
    public Map<String, Object> queryRechargeInfoList(QueryParam queryParam) {

        if( (queryParam.getPageNum() * queryParam.getPageSize()) > 1000){
            return null;
        }

        log.debug("充值记录查询参数 {}",  queryParam);
        
        Map<String, Object> reMap = new HashMap<>();
        List<RechargeInfo> rechargeInfoList = new ArrayList<RechargeInfo>();

        String sjjhUserId = expenseManagementMapper.querySjjhUserIdByYysjUseId(queryParam.getUserId());
        
        log.debug("云验数据Id {} 数据交互Id {}", queryParam.getUserId(), sjjhUserId);
        
        if(sjjhUserId == null || "".equals(sjjhUserId)){
            reMap.put(Constant.DATA_LIST, rechargeInfoList);
            reMap.put(Constant.TOTAL, 0);
            return reMap;
        }
        
        ChargeRecordRes chargeRecordRes = orderActionInterface.getChargeList(sjjhUserId, queryParam.getBeginTime(),
                                            queryParam.getEndTime(), queryParam.getPageNum(),
                                            queryParam.getPageSize());
        List<ChargeInfo> chargeInfoList = chargeRecordRes.getList();

        for (ChargeInfo chargeInfo : chargeInfoList){
            RechargeInfo rechargeInfo = new RechargeInfo();
            rechargeInfo.setId(queryParam.getUserId());
            rechargeInfo.setTime(chargeInfo.getDate());
            
            String money = chargeInfo.getMoney().toString();
            if(money.length() > 3){
                money = money.substring(0, money.length()-3) + "." + money.substring(money.length()-3, money.length());
            } else {
                if(money.length() == 3){
                    money = "0."+money;
                } else if(money.length() == 2){
                    money = "0.0"+money;
                } else if(money.length() == 1) {
                    money = "0.00"+money;
                } else {
                    money = "0";
                }
            }
            rechargeInfo.setPrice(money);
            
            rechargeInfo.setType(chargeInfo.getChargeType());
            
            String status = "未转账".equals(chargeInfo.getChargeType()) ? "失败" : "成功";
            rechargeInfo.setStatus(status);

            rechargeInfoList.add(rechargeInfo);
            
            log.debug("充值记录 {}",  rechargeInfo);
        }

        reMap.put(Constant.DATA_LIST, rechargeInfoList);
        reMap.put(Constant.TOTAL, chargeRecordRes.getTotal());

        return reMap;
    }
}
